<?php
//
// +----------------------------------------------------------------------+
// | PHP wersja 4.0                                                       |
// +----------------------------------------------------------------------+
// | Prawa autorskie (c) 1997-2001 The PHP Group                          |
// +----------------------------------------------------------------------+
// | Niniejszy kod rdowy jest objty licencj jzyka PHP w wersji 2.02,|
// | ktra do pakietu zostaa doczona w postaci pliku LICENSE, a ponadto|
// | jest dostpna na stronie internetowej pod adresem                    |
// | http://www.php.net/license/2_02.txt.                                 |
// | Jeli nie dysponujesz kopi licencji jzyka PHP i nie moesze jej    |
// | pobra ze strony internetowej, wtedy prosz wysa wiadomo pod     |
// | adres license@php.net, dziki czemu zostanie ona natychmiast         |
// | przesana.                                                           |
// +----------------------------------------------------------------------+
// | Autorzy: Sebastian Bergmann <sb@sebastian-bergmann.de>               |
// +----------------------------------------------------------------------+
//
// $Id: Iterate.php,v 1.1.1.3 2001/12/14 22:14:03 zarzycki Exp $
//

require_once 'Benchmark/Timer.php';

/**
* Benchmark::Benchmark_Iterate
* 
* Cel:
* 
*     Pomiar wydajnoci
* 
* Przykad:
*   a) 
*     require_once 'Benchmark/Iterate.php';
*     $benchmark = new Benchmark_Iterate;
* 
*     function foo($string) {
*         print $string . '<br>';
*     }
* 
*     $benchmark->run(100, 'foo', 'test');
*     $result = $benchmark->get();
*
*   b)
*     require_once 'Benchmark/Iterate.php';
*     $benchmark = new Benchmark_Iterate;
* 
*     class myclass{
*
*       function foo($string) {
*             print $string . '<br>';
*       }
*     }
* 
*     $benchmark->run(100, 'myclass::foo', 'test');
*     $result = $benchmark->get();
*
*   c)
*     require_once 'Benchmark/Iterate.php';
*     $benchmark = new Benchmark_Iterate;
* 
*     class myclass{
*
*       function foo($string) {
*             print $string . '<br>';
*       }
*     }
*
*     $myobj = new myclass();
* 
*     $benchmark->run(100, 'myobj->foo', 'test');
*     $result = $benchmark->get();
*
* @author   Sebastian Bergmann <sb@sebastian-bergmann.de>
* @version  $Revision: 1.1.1.3 $
* @access   public
*/

class Benchmark_Iterate extends Benchmark_Timer {
    /**
    * Pomiar szybkoci dziaania funkcji.
    *
    * @access public
    */

    function run() {
        $arguments     = func_get_args();

        $iterations    = array_shift($arguments);
        $function_name = array_shift($arguments);
    
        if (strstr($function_name, '::')) {
          $function_name = explode('::', $function_name);
          $objectmethod = $function_name[1];
        }

        // Jeli dla obiektu jest wywoywana metoda, wtedy naley uy call_user_method
        if (strstr($function_name, '->')) {
            $function_name = explode('->', $function_name);
            $objectname = $function_name[0];

            global ${$objectname};
            $objectmethod = $function_name[1];

            for ($i = 1; $i <= $iterations; $i++) {
                $this->setMarker('start_' . $i);
                call_user_method_array($function_name[1], ${$objectname}, $arguments);
                $this->setMarker('end_' . $i);
            }
            return(0);
        }

        for ($i = 1; $i <= $iterations; $i++) {
            $this->setMarker('start_' . $i);
            call_user_func_array($function_name, $arguments);
            $this->setMarker('end_' . $i);
        }
    }

    /**
    * Zwraca wyniki pomiaru szybkoci dziaania.
    *
    * $result[x           ] = czas wykonywania iteracji x
    * $result['mean'      ] = redni czas wykonywania
    * $result['iterations'] = liczba iteracji
    *
    * @return array $result
    * @access public
    */

    function get() {
        $result = array();
        $total  = 0;

        $iterations = count($this->markers)/2;

        for ($i = 1; $i <= $iterations; $i++) {
            $time = $this->timeElapsed('start_'.$i , 'end_'.$i);

            if (extension_loaded('bcmath')) {
                $total = bcadd($total, $time, 6);
            } else {
                $total = $total + $time;
            }
            
            $result[$i] = $time;
        }

        if (extension_loaded('bcmath')) {
            $result['mean'] = bcdiv($total, $iterations, 6);
        } else {
            $result['mean'] = $total / $iterations;
        }

        $result['iterations'] = $iterations;

        return $result;
    }
}
?>
